import { BaseEvent } from '#application/base/baseEvent'
import CharacterHairRepository from '#repositories/characterHairRepository'
import characterRepository from '#repositories/characterRepository'

interface IPayload {
  id: number
}

export default class characterHairDeleteEvent extends BaseEvent {
  public listen(): void {
    this.socket.on('gm:characterHair:remove', this.handleEvent.bind(this))
  }

  private async handleEvent(data: IPayload, callback: (response: boolean) => void): Promise<void> {
    const character = await characterRepository.getById(this.socket.characterId as number)
    if (!character) return callback(false)

    if (character.role !== 'gm') {
      return callback(false)
    }

    try {
      const characterHair = await CharacterHairRepository.getById(data.id)
      if (characterHair) {
        await characterHair.delete()
      }

      callback(true)
    } catch (error) {
      this.logger.error(`Error deleting character type ${data.id}: ${error instanceof Error ? error.message : String(error)}`)
      callback(false)
    }
  }
}
